﻿namespace U2UConsult.T9.Sample
{
    using System.Windows;
    using System.Windows.Controls;

    /// <summary>
    /// Interaction logic for MainWindow.xaml
    /// </summary>
    public partial class MainWindow : Window
    {
        /// <summary>
        /// MVVM ViewModel.
        /// </summary>
        private T9ViewModel viewModel;

        /// <summary>
        /// Initializes a new instance of the MainWindow class.
        /// </summary>
        public MainWindow()
        {
            InitializeComponent();

            this.viewModel = new T9ViewModel();
            this.viewModel.MinimumAutoCompleteTreshold = 3;
            this.viewModel.MaximumAutoCompleteTreshold = 4;
            this.DataContext = this.viewModel;
        }

        /// <summary>
        /// Normalizes the input.
        /// </summary>
        /// <param name="sender">Sender of the event.</param>
        /// <param name="e">Event arguments.</param>
        private void NormalizeButton_Click(object sender, RoutedEventArgs e)
        {
            this.EncodingDestinationTextBlock.Text = this.viewModel.RemoveDiacritics(this.SourceTextBox.Text);
        }

        /// <summary>
        /// Encodes the input to T9.
        /// </summary>
        /// <param name="sender">Sender of the event.</param>
        /// <param name="e">Event arguments.</param>
        private void EncodeButton_Click(object sender, RoutedEventArgs e)
        {
            this.EncodingDestinationTextBlock.Text = this.viewModel.EncodeString(this.SourceTextBox.Text);
        }

        /// <summary>
        /// Adds a digit.
        /// </summary>
        /// <param name="sender">Sender of the event.</param>
        /// <param name="e">Event arguments.</param>
        private void DigitButton_Click(object sender, RoutedEventArgs e)
        {
            this.EncodedTextBox.Text += (sender as Control).Tag;
        }

        /// <summary>
        /// Enables Autocomplete mode.
        /// </summary>
        /// <param name="sender">Sender of the event.</param>
        /// <param name="e">Event arguments.</param>
        private void AutoComplete_Checked(object sender, RoutedEventArgs e)
        {
            this.viewModel.IsAutoComplete = true;
        }

        /// <summary>
        /// Disables Autocomplete mode.
        /// </summary>
        /// <param name="sender">Sender of the event.</param>
        /// <param name="e">Event arguments.</param>
        private void AutoComplete_Unchecked(object sender, RoutedEventArgs e)
        {
            this.viewModel.IsAutoComplete = false;
        }

        /// <summary>
        /// Selects a candidate.
        /// </summary>
        /// <param name="sender">Sender of the event.</param>
        /// <param name="e">Event arguments.</param>
        private void CandidatesListBox_SelectionChanged(object sender, SelectionChangedEventArgs e)
        {
            if (this.CandidatesListBox.SelectedIndex < 0)
            {
                return;
            }

            this.EncodedTextBox.Text = this.viewModel.EncodeString(this.CandidatesListBox.SelectedValue.ToString());
        }
    }
}
